# Open Trip Plan

Open Trip Plan allows to plan a trip by adding markers on a map (using the Folium library to display an OpenStreetMap map) associated with a note.

Open Trip Plan is on PyPi. To install it, run:

```sh
pip install opentripplan
```

Tested on Linux. Should work on any platform.

Open Trip Plan is already usable but would be better with a lot of other features. Some ara listed here:
https://github.com/kleag/opentripplan/issues

Don't hesitate to create a new issue if you think at other features. And contribute them if you can!


